import { AutoMap } from '@automapper/classes';
import {
  IsOptional,
  IsString,
  IsBoolean,
  IsDate,
  IsInt,
  MinLength,
  ValidateIf,
} from 'class-validator';
import { FrequencyType } from '../entities/frequencyEnum';
import { Address } from '../entities/address';

export class CreateAdRequest {
  @IsString()
  @IsOptional()
  @AutoMap()
  uuid?: string;

  @IsString()
  @AutoMap()
  userUuid: string;

  @ValidateIf((ad) => (ad.passenger ? false : true))
  @IsBoolean()
  @AutoMap()
  driver?: boolean;

  @ValidateIf((ad) => (ad.driver ? false : true))
  @IsBoolean()
  @AutoMap()
  passenger?: boolean;

  @AutoMap()
  frequency: FrequencyType;

  @AutoMap()
  fromDate: Date;

  @AutoMap()
  toDate: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  monTime?: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  tueTime?: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  wedTime?: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  thuTime?: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  friTime?: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  satTime?: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  sunTime?: Date;

  @IsInt()
  @IsOptional()
  @AutoMap()
  monMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  tueMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  wedMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  thuMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  friMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  satMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  sunMargin?: number;

  @ValidateIf((ad) => (ad.passenger ? false : true))
  @IsInt()
  @AutoMap()
  seatsDriver?: number;

  @ValidateIf((ad) => (ad.driver ? false : true))
  @IsInt()
  @AutoMap()
  seatsPassenger?: number;

  @IsDate()
  @IsOptional()
  @AutoMap()
  createdAt?: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  updatedAt?: Date;

  @MinLength(2)
  @AutoMap()
  addresses?: Array<Address>;
}
